==> ldapsaisie_3.0.0-1.tar.gz: ldapsaisie_clean3/src/tmp/c8c9cd1a584e77555fe15356f8deb390540e8c6e_0.ls.baseconnected.tpl.php <==
<?php
/* Smarty version 3.1.33-dev-7, created on 2020-07-07 16:03:20
  from 'ls:baseconnected.tpl' */

/* @var Smarty_Internal_Template $_smarty_tpl */
if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
  'version' => '3.1.33-dev-7',
  'unifunc' => 'content_5f0480a858ee38_62380654',
  'has_nocache_code' => false,
  'file_dependency' => 
  array (
    'c8c9cd1a584e77555fe15356f8deb390540e8c6e' => 
    array (
      0 => 'ls:baseconnected.tpl',
      1 => 1591109476,
      2 => 'ls',
    ),
  ),
  'includes' => 
  array (
  ),
),false)) {
function content_5f0480a858ee38_62380654 (Smarty_Internal_Template $_smarty_tpl) {
$_smarty_tpl->_loadInheritance();
$_smarty_tpl->inheritance->init($_smarty_tpl, true);
?>

<?php 
$_smarty_tpl->inheritance->instanceBlock($_smarty_tpl, 'Block_11976331365f0480a857ca72_33021150', "body");
?>

<?php $_smarty_tpl->inheritance->endChild($_smarty_tpl, 'ls:base.tpl');
}
/* {block "content"} */
class Block_9044322215f0480a858e3e2_04496081 extends Smarty_Internal_Block
{
public function callBlock(Smarty_Internal_Template $_smarty_tpl) {
}
}
/* {/block "content"} */
/* {block "body"} */
class Block_11976331365f0480a857ca72_33021150 extends Smarty_Internal_Block
{
public $subBlocks = array (
  'body' => 
  array (
    0 => 'Block_11976331365f0480a857ca72_33021150',
  ),
  'content' => 
  array (
    0 => 'Block_9044322215f0480a858e3e2_04496081',
  ),
);
public function callBlock(Smarty_Internal_Template $_smarty_tpl) {
$_smarty_tpl->_checkPlugins(array(0=>array('file'=>'/usr/share/php/smarty3/plugins/function.html_options.php','function'=>'smarty_function_html_options',),));
?>

<table id='main'>
  <tr>
    <td rowspan=2 id='left'>
      <button id="toggle-menu"><img src="<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['img'][0], array( array('name'=>'toggle-menu'),$_smarty_tpl ) );?>
" alt='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>"Show/hide menu"),$_smarty_tpl ) );?>
' title='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>"Show/hide menu"),$_smarty_tpl ) );?>
'/></button>
      <a href=''><img src='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['img'][0], array( array('name'=>'logo'),$_smarty_tpl ) );?>
' alt='Logo' id='logo'/></a>

      <?php if (isset($_smarty_tpl->tpl_vars['LSsession_subDn']->value) && $_smarty_tpl->tpl_vars['LSsession_subDn']->value != '') {?>
        <form action="" method='post' id='LSsession_topDn_form'>
          <label><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['label_level']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>

            <a href="?LSsession_refresh"><img src='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['img'][0], array( array('name'=>'refresh'),$_smarty_tpl ) );?>
' alt='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['_refresh']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' title='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['_refresh']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' /></a>
            <select name='LSsession_topDn' id='LSsession_topDn'>
              <?php echo smarty_function_html_options(array('values'=>$_smarty_tpl->tpl_vars['LSsession_subDn_indexes']->value,'output'=>$_smarty_tpl->tpl_vars['LSsession_subDn_names']->value,'selected'=>$_smarty_tpl->tpl_vars['LSsession_subDn']->value),$_smarty_tpl);?>

            </select>
          </label>
        </form>
      <?php }?>

      <?php if ($_smarty_tpl->tpl_vars['globalSearch']->value && $_smarty_tpl->tpl_vars['LSaccess']->value) {?>
      <form action='search' method='post' class='LSview_search LSglobal_search'>
        <input type='hidden' name='LSsearch_submit' value='1'/>
        <input type='text' name='pattern' class='LSview_search LSglobal_search' placeholder='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>'Global search'),$_smarty_tpl ) );?>
' required="required"/>
        <input type='image' src='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['img'][0], array( array('name'=>'find'),$_smarty_tpl ) );?>
' alt='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>'Global search'),$_smarty_tpl ) );?>
' title='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>'Global search'),$_smarty_tpl ) );?>
' />
      </form>
      <?php }?>

      <ul class='menu'>
      <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSaccess']->value, 'label', false, 'LSobject_type');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['LSobject_type']->value => $_smarty_tpl->tpl_vars['label']->value) {
?>
        <li class='menu'><a href='object/<?php echo rawurlencode($_smarty_tpl->tpl_vars['LSobject_type']->value);?>
' class='menu'><?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>$_smarty_tpl->tpl_vars['label']->value),$_smarty_tpl ) );?>
</a></li>
      <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);?>
      <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSaddonsViewsAccess']->value, 'access');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['access']->value) {
?>
        <?php if ($_smarty_tpl->tpl_vars['access']->value['showInMenu']) {?>
        <li class='menu'><a href='addon/<?php echo rawurlencode($_smarty_tpl->tpl_vars['access']->value['LSaddon']);?>
/<?php echo rawurlencode($_smarty_tpl->tpl_vars['access']->value['id']);?>
' class='menu'><?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>$_smarty_tpl->tpl_vars['access']->value['label']),$_smarty_tpl ) );?>
</a></li>
        <?php }?>
      <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);?>
      </ul>
    </td>
    <td id='status'>
    <span><?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>"Language"),$_smarty_tpl ) );?>
 : <img id='LSlang' src='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['img'][0], array( array('name'=>$_smarty_tpl->tpl_vars['LSlang']->value),$_smarty_tpl ) );?>
' alt='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSlang']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' title='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSlang']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'/></span>
    <form action='' methode='post' style='display: none' class='LSlang_hidden'>
      <select name='lang'>
      <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSlanguages']->value, 'lang');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['lang']->value) {
?>
        <option value='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['lang']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['lang']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</option>
      <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);?>
      </select>
      <input type='submit' value='->'/>
    </form>
    <?php if ($_smarty_tpl->tpl_vars['displaySelfAccess']->value) {
echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>mb_convert_encoding(htmlspecialchars("Connected as", ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8')),$_smarty_tpl ) );?>
 <span id='user_name'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSsession_username']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</span><?php }?>
    <a href='?LSsession_refresh=1'><img src='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['img'][0], array( array('name'=>'refresh'),$_smarty_tpl ) );?>
' alt="<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>"Refresh my access rights"),$_smarty_tpl ) );?>
" title="<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>"Refresh my access rights"),$_smarty_tpl ) );?>
" /></a>
    <?php if ($_smarty_tpl->tpl_vars['displayLogoutBtn']->value) {?> <a href='?LSsession_logout'><img src='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['img'][0], array( array('name'=>'logout'),$_smarty_tpl ) );?>
' alt='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>mb_convert_encoding(htmlspecialchars("Logout", ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8')),$_smarty_tpl ) );?>
' title='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>mb_convert_encoding(htmlspecialchars("Logout", ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8')),$_smarty_tpl ) );?>
' /></a><?php }?>
    </td>
  </tr>
  <tr>
    <td id='right'>

<?php 
$_smarty_tpl->inheritance->instanceBlock($_smarty_tpl, 'Block_9044322215f0480a858e3e2_04496081', "content", $this->tplIndex);
?>


    </td>
  </tr>
</table>
<?php
}
}
/* {/block "body"} */
}

==> ldapsaisie_3.0.1-1.tar.gz: ldapsaisie_clean3/src/tmp/c8c9cd1a584e77555fe15356f8deb390540e8c6e_0.ls.baseconnected.tpl.php <==
<?php
/* Smarty version 3.1.33-dev-7, created on 2020-08-06 13:15:28
  from 'ls:baseconnected.tpl' */

/* @var Smarty_Internal_Template $_smarty_tpl */
if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
  'version' => '3.1.33-dev-7',
  'unifunc' => 'content_5f2be65009e458_87728432',
  'has_nocache_code' => false,
  'file_dependency' => 
  array (
    'c8c9cd1a584e77555fe15356f8deb390540e8c6e' => 
    array (
      0 => 'ls:baseconnected.tpl',
      1 => 1596712427,
      2 => 'ls',
    ),
  ),
  'includes' => 
  array (
  ),
),false)) {
function content_5f2be65009e458_87728432 (Smarty_Internal_Template $_smarty_tpl) {
$_smarty_tpl->_loadInheritance();
$_smarty_tpl->inheritance->init($_smarty_tpl, true);
?>

<?php 
$_smarty_tpl->inheritance->instanceBlock($_smarty_tpl, 'Block_108136095f2be65008e827_55460479', "body");
?>

<?php $_smarty_tpl->inheritance->endChild($_smarty_tpl, 'ls:base.tpl');
}
/* {block "content"} */
class Block_12473643665f2be65009d523_11636351 extends Smarty_Internal_Block
{
public function callBlock(Smarty_Internal_Template $_smarty_tpl) {
}
}
/* {/block "content"} */
/* {block "body"} */
class Block_108136095f2be65008e827_55460479 extends Smarty_Internal_Block
{
public $subBlocks = array (
  'body' => 
  array (
    0 => 'Block_108136095f2be65008e827_55460479',
  ),
  'content' => 
  array (
    0 => 'Block_12473643665f2be65009d523_11636351',
  ),
);
public function callBlock(Smarty_Internal_Template $_smarty_tpl) {
$_smarty_tpl->_checkPlugins(array(0=>array('file'=>'/usr/share/php/smarty3/plugins/function.html_options.php','function'=>'smarty_function_html_options',),));
?>

<table id='main'>
  <tr>
    <td rowspan=2 id='left'>
      <button id="toggle-menu"><img src="<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['img'][0], array( array('name'=>'toggle-menu'),$_smarty_tpl ) );?>
" alt='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>"Show/hide menu"),$_smarty_tpl ) );?>
' title='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>"Show/hide menu"),$_smarty_tpl ) );?>
'/></button>
      <a href=''><img src='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['img'][0], array( array('name'=>'logo'),$_smarty_tpl ) );?>
' alt='Logo' id='logo'/></a>

      <?php if (isset($_smarty_tpl->tpl_vars['LSsession_subDn']->value) && $_smarty_tpl->tpl_vars['LSsession_subDn']->value != '') {?>
        <form action="" method='post' id='LSsession_topDn_form'>
          <label><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSsession_subDn_level']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>

            <a href="?LSsession_refresh"><img src='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['img'][0], array( array('name'=>'refresh'),$_smarty_tpl ) );?>
' alt='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSsession_subDn_refresh']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' title='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSsession_subDn_refresh']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' /></a>
            <select name='LSsession_topDn' id='LSsession_topDn'>
              <?php echo smarty_function_html_options(array('values'=>$_smarty_tpl->tpl_vars['LSsession_subDn_indexes']->value,'output'=>$_smarty_tpl->tpl_vars['LSsession_subDn_names']->value,'selected'=>$_smarty_tpl->tpl_vars['LSsession_subDn']->value),$_smarty_tpl);?>

            </select>
          </label>
        </form>
      <?php }?>

      <?php if ($_smarty_tpl->tpl_vars['globalSearch']->value && $_smarty_tpl->tpl_vars['LSaccess']->value) {?>
      <form action='search' method='post' class='LSview_search LSglobal_search'>
        <input type='hidden' name='LSsearch_submit' value='1'/>
        <input type='text' name='pattern' class='LSview_search LSglobal_search' placeholder='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>'Global search'),$_smarty_tpl ) );?>
' required="required"/>
        <input type='image' src='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['img'][0], array( array('name'=>'find'),$_smarty_tpl ) );?>
' alt='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>'Global search'),$_smarty_tpl ) );?>
' title='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>'Global search'),$_smarty_tpl ) );?>
' />
      </form>
      <?php }?>

      <ul class='menu'>
      <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSaccess']->value, 'label', false, 'LSobject_type');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['LSobject_type']->value => $_smarty_tpl->tpl_vars['label']->value) {
?>
        <li class='menu'><a href='object/<?php echo rawurlencode($_smarty_tpl->tpl_vars['LSobject_type']->value);?>
' class='menu'><?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>$_smarty_tpl->tpl_vars['label']->value),$_smarty_tpl ) );?>
</a></li>
      <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);?>
      <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSaddonsViewsAccess']->value, 'access');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['access']->value) {
?>
        <?php if ($_smarty_tpl->tpl_vars['access']->value['showInMenu']) {?>
        <li class='menu'><a href='addon/<?php echo rawurlencode($_smarty_tpl->tpl_vars['access']->value['LSaddon']);?>
/<?php echo rawurlencode($_smarty_tpl->tpl_vars['access']->value['id']);?>
' class='menu'><?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>$_smarty_tpl->tpl_vars['access']->value['label']),$_smarty_tpl ) );?>
</a></li>
        <?php }?>
      <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);?>
      </ul>
    </td>
    <td id='status'>
    <span><?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>"Language"),$_smarty_tpl ) );?>
 : <img id='LSlang' src='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['img'][0], array( array('name'=>$_smarty_tpl->tpl_vars['LSlang']->value),$_smarty_tpl ) );?>
' alt='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSlang']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' title='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSlang']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'/></span>
    <form action='' methode='post' style='display: none' class='LSlang_hidden'>
      <select name='lang'>
      <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSlanguages']->value, 'lang');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['lang']->value) {
?>
        <option value='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['lang']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['lang']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</option>
      <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);?>
      </select>
      <input type='submit' value='->'/>
    </form>
    <?php if ($_smarty_tpl->tpl_vars['displaySelfAccess']->value) {
echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>mb_convert_encoding(htmlspecialchars("Connected as", ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8')),$_smarty_tpl ) );?>
 <span id='user_name'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSsession_username']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</span><?php }?>
    <a href='?LSsession_refresh=1'><img src='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['img'][0], array( array('name'=>'refresh'),$_smarty_tpl ) );?>
' alt="<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>"Refresh my access rights"),$_smarty_tpl ) );?>
" title="<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>"Refresh my access rights"),$_smarty_tpl ) );?>
" /></a>
    <?php if ($_smarty_tpl->tpl_vars['displayLogoutBtn']->value) {?> <a href='?LSsession_logout'><img src='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['img'][0], array( array('name'=>'logout'),$_smarty_tpl ) );?>
' alt='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>mb_convert_encoding(htmlspecialchars("Logout", ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8')),$_smarty_tpl ) );?>
' title='<?php echo call_user_func_array( $_smarty_tpl->smarty->registered_plugins[Smarty::PLUGIN_FUNCTION]['tr'][0], array( array('msg'=>mb_convert_encoding(htmlspecialchars("Logout", ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8')),$_smarty_tpl ) );?>
' /></a><?php }?>
    </td>
  </tr>
  <tr>
    <td id='right'>

<?php 
$_smarty_tpl->inheritance->instanceBlock($_smarty_tpl, 'Block_12473643665f2be65009d523_11636351', "content", $this->tplIndex);
?>


    </td>
  </tr>
</table>
<?php
}
}
/* {/block "body"} */
}
